# encoding: utf-8
'''
This module contains the meta-data of the package.
'''

__author__ = 'David Kundih'
__copyright__ = 'Copyright © 2021- David Kundih'
__credits__ = [
	'dkundih <https://github.com/dkundih>'

]
__license__ = 'Apache 2.0 License'
__version__ = '1.0.1+'


#imports essential functions from the duality package.
from duality import eoq as eoq
from duality import hub
from duality.misc.global_functions import *
from duality import montecarlo
from unin.misc._meta import (
	__author__,
	__copyright__,
	__credits__,
	__license__,
	__version__,
)

import pandas as pd
import matplotlib.pyplot as plt
import random
import numpy as np
import time
import datetime
import math